@@ -7,7 +7,7 @@
     y <- as.matrix(y)
     if (length(x) != nrow(y)) 
         stop("Dimensions do not match")
-    ytimes <- time(ts(rep(NA, ncol(y)), s = start, f = frequency))
+    ytimes <- time(ts(rep(NA, ncol(y)), start = start, frequency = frequency))
     if(any(colnames(y) == "")){        
         if (max(abs(ytimes - floor(ytimes))) < 1e-09) 
             ylab <- paste(ytimes)
